@@ -1,23 +1,24 @@
 distinctDis <-
-function(dis, method=1:3, standardized = FALSE){
+function(dis, method=c("Rb","AV","FV","NN","full"), standardized = FALSE){
 
-    if (any(is.na(match(method, 1:3)))) 
+    if (any(is.na(match(method, c("Rb","AV","FV","NN","full"))))) 
         stop("unconvenient method")
+    if(any(method=="full")) method <- c("Rb","AV","FV","NN")
     nbMeth <- length(method)
     dis <- as.matrix(dis)
     nsp <- nrow(dis)
     resWeights <- as.data.frame(matrix(0, nsp, nbMeth))
-    rownames(resWeights) <- attributes(dis)$Labels
+    rownames(resWeights) <- rownames(dis)
     for (k in 1:nbMeth) {
         meth <- method[k]
-        if (meth == 1) {
+        if (meth == "Rb") {
             ori <- abs(eigen(dis)$vector[, 1])
             if(standardized)
                 ori <- ori/sum(ori)
             resWeights[, k] <- ori
             names(resWeights)[k] <- "Rb"
         }
-        if (meth == 2) {
+        if (meth == "AV") {
             fun <- function(i){
                 return(mean(dis[i, -i]))
             }
@@ -27,7 +28,7 @@ function(dis, method=1:3, standardized = FALSE){
             resWeights[, k] <-  ori
             names(resWeights)[k] <- "AV"
         }
-        if (meth == 3) {
+        if (meth == "FV") {
             fun <- function(i){
                 return(mean(dis[i, ]))
             }
@@ -37,6 +38,17 @@ function(dis, method=1:3, standardized = FALSE){
             resWeights[, k] <-  ori
             names(resWeights)[k] <- "FV"
         }
+        if (meth == "NN") {
+            fun <- function(i){
+                return(min(dis[i, -i]))
+            }
+            ori <- sapply(1:nsp, fun)
+            if(standardized)
+                ori <- ori/sum(ori)
+            resWeights[, k] <-  ori
+            names(resWeights)[k] <- "NN"
+        }
+
     }
     return(resWeights)
     
